package mathgrammar.drivers;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;

import mathgrammar.*;
import mathgrammar.ast.Expr;

import edu.umn.cs.melt.copper.runtime.logging.CopperException;

/*
 * Driver for the "MathExampleAST" parser.
 * Reads lines from System.in and calls the parser on them
 * until a blank line is entered.
 * 
 * @author schwerdf
 */
public class MathExampleASTDriver
{
    public static void main(String[] args)
    {
	BufferedReader bin = null;
	String buf = "";
	Expr answer;

	// Construct a buffered reader from standard input.
        bin = new BufferedReader(new InputStreamReader(System.in));

	// Construct an instance of the parser.
	MathExampleAST parser = new MathExampleAST();

	System.err.println("Enter lines of input to the parser, blank line to exit.");

	while(true)
	{
	    // Output a prompt for a line.
	    System.err.print(">>> ");
	    System.err.flush();

	    // Read in a line from standard input.
	    try { buf = bin.readLine(); }
	    catch(IOException ex) { System.exit(1); }

	    // Exit if it was a blank line.
	    if(buf.equals("")) break;

	    answer = null;

	    // Parse the line that was read in.
	    try { answer = parser.parse(buf); }
	    // If an exception occurred in reading from the string, exit.
	    catch(IOException ex) { System.exit(1); }
	    // If there was a parse error, display it.
	    catch(CopperException ex) { System.err.println(ex.getMessage()); }

	    // Print the result from the parser, if there was any.
	    if(answer != null)
	    {
		System.out.println(answer.toString() + " = " + answer.compute());
	    }
	}
    }
}
